@@ -80,6 +80,7 @@ taylorexp <- function(a, b, c, d, q, thr) {
   # x is the number of cases need to be replaced solved based on the taylor expansion
   # this is the (linear approximation) of the original/unsquared term around the value of q
   x <- (thr - log(a * (d - q) / (b * (c + q))) / sqrt((1 / a + 1 / b + 1 / (c + q) + 1 / (d - q)))) / d1unsquare + q
+  if (is.na(x)) {x <- 0}
   return(x)
 }
 
@@ -131,7 +132,8 @@ getswitch <- function(table_bstart, thr_t, switch_trm, n_obs) {
     b_tryall <- b - (b - 1) * (1 - as.numeric(switch_trm))
     tryall_t <- get_t_kfnl(a_tryall, b_tryall, c_tryall, d_tryall)
     tryall_est <- log(a_tryall*d_tryall/c_tryall/b_tryall)
-    allnotenough <- isTRUE(thr_t - tryall_t > 0 & tryall_est*est_eff_start > 0)
+    allnotenough <- isTRUE(thr_t - tryall_t > 0 & 
+                               tryall_est * est_eff_start >= 0)
   }
   if (t_start > thr_t) {
     # transfer cases from A to B or D to C to decrease odds ratio
@@ -141,7 +143,7 @@ getswitch <- function(table_bstart, thr_t, switch_trm, n_obs) {
     b_tryall <- b + (a - 1) * (1 - as.numeric(switch_trm))
     tryall_t <- get_t_kfnl(a_tryall, b_tryall, c_tryall, d_tryall)
     tryall_est <- log(a_tryall*d_tryall/c_tryall/b_tryall)
-    allnotenough <- isTRUE(tryall_t - thr_t > 0 & tryall_est*est_eff_start > 0)
+    allnotenough <- isTRUE(tryall_t - thr_t > 0 & tryall_est*est_eff_start >= 0)
   }
 
   ### run following if transfering one row is enough
@@ -266,12 +268,21 @@ getswitch <- function(table_bstart, thr_t, switch_trm, n_obs) {
   std_err_final <- sqrt(1 / a_final + 1 / b_final + 1 / c_final + 1 / d_final)
   t_final <- est_eff_final / std_err_final
   table_final <- matrix(c(a_final, b_final, c_final, d_final), byrow = TRUE, 2, 2)
+  
+  ### switch_trm allnotenough final(total_switch)
+  #*. 1.         1.           abs(a - a_final) + abs(c - c_final)
+  #*. 1.         0.           abs(c - c_final)
+  #*. 0.         1.           abs(a - a_final) + abs(c - c_final)
+  #*. 0.         0.           abs(a - a_final)
+  
+  ### final includes all switches for two rows 
   if (switch_trm == allnotenough) {
     final <- abs(a - a_final) + as.numeric(allnotenough) * abs(c - c_final)
   } else {
     final <- abs(c - c_final) + as.numeric(allnotenough) * abs(a - a_final)
   }
 
+  ### final_extra is the extra switch
   if (allnotenough) {
     taylor_pred <- NA
     perc_bias_pred <- NA
@@ -330,7 +341,7 @@ get_pi <- function(odds_ratio, std_err, n_obs, n_trm) {
 #' @importFrom stats chisq.test
 chisq_p <- function(a, b, c, d){
   table <- matrix(c(a,b,c,d), byrow = TRUE, 2, 2)
-  p <- chisq.test(table,correct = FALSE)$p.value
+  p <- suppressWarnings(chisq.test(table,correct = FALSE)$p.value) 
   return(p)
 }
 
@@ -345,7 +356,7 @@ fisher_p <- function(a, b, c, d){
 # get chi-square value for chi-square test 
 chisq_value <- function(a, b, c, d){
   table <- matrix(c(a,b,c,d), byrow = TRUE, 2, 2)
-  value <- chisq.test(table,correct = FALSE)$statistic
+  value <- suppressWarnings(chisq.test(table,correct = FALSE)$statistic)
   return(value)
 }
 
@@ -356,8 +367,7 @@ fisher_oddsratio <- function(a, b, c, d){
   return(value)
 }
 
-getswitch_chisq <- function(a, b, c, d, thr_p = 0.05, switch_trm = TRUE){
-odds_ratio <- a*d/(b*c)
+getswitch_chisq <- function(a, b, c, d, odds_ratio, thr_p = 0.05, switch_trm = TRUE){
 n_cnt <- a+b
 n_trm <- c+d
 n_obs <- n_cnt + n_trm
@@ -396,23 +406,23 @@ if (dcroddsratio_start) {
 ### check whether it is enough to transfer all cases in one row
 if (!dcroddsratio_start) {
   # transfer cases from B to A or C to D to increase odds ratio
-  c_tryall <- c - (c - 1) * as.numeric(switch_trm)
-  d_tryall <- d + (c - 1) * as.numeric(switch_trm)
-  a_tryall <- a + (b - 1) * (1 - as.numeric(switch_trm))
-  b_tryall <- b - (b - 1) * (1 - as.numeric(switch_trm))
+  c_tryall <- c - c * as.numeric(switch_trm)
+  d_tryall <- d + c * as.numeric(switch_trm)
+  a_tryall <- a + b * (1 - as.numeric(switch_trm))
+  b_tryall <- b - b * (1 - as.numeric(switch_trm))
   tryall_p <- chisq_p(a_tryall, b_tryall, c_tryall, d_tryall)
   tryall_est <- log(a_tryall*d_tryall/c_tryall/b_tryall)
-  allnotenough <- isTRUE((thr_p-tryall_p)*tryall_est< 0 & tryall_est*est > 0)
+  allnotenough <- isTRUE((thr_p-tryall_p)*tryall_est< 0 & tryall_est*est >= 0)
 }
 if (dcroddsratio_start ) {
   # transfer cases from A to B or D to C to decrease odds ratio
-  c_tryall <- c + (d - 1) * as.numeric(switch_trm)
-  d_tryall <- d - (d - 1) * as.numeric(switch_trm)
-  a_tryall <- a - (a - 1) * (1 - as.numeric(switch_trm))
-  b_tryall <- b + (a - 1) * (1 - as.numeric(switch_trm))
+  c_tryall <- c + d * as.numeric(switch_trm)
+  d_tryall <- d - d * as.numeric(switch_trm)
+  a_tryall <- a - a * (1 - as.numeric(switch_trm))
+  b_tryall <- b + a * (1 - as.numeric(switch_trm))
   tryall_p <- chisq_p(a_tryall, b_tryall, c_tryall, d_tryall)
   tryall_est <- log(a_tryall*d_tryall/c_tryall/b_tryall)
-  allnotenough <- isTRUE((thr_p-tryall_p)*tryall_est> 0  & tryall_est*est > 0)
+  allnotenough <- isTRUE((thr_p-tryall_p)*tryall_est> 0  & tryall_est*est >= 0)
 }
 
 ### run following if transfering one row is enough
@@ -681,25 +691,19 @@ if (allnotenough) {
   final_extra <- 0
 }
 
-total_switch <- final + allnotenough*final_extra
-
 result <- list(final_switch = final, User_enter_value = table_start, 
                Transfer_Table = table_final, 
                p_final = p_final, chisq_final = chisq_final,
                needtworows = allnotenough, taylor_pred = taylor_pred,
                perc_bias_pred = perc_bias_pred, final_extra = final_extra, 
-               dcroddsratio_ob = dcroddsratio_ob, total_switch = total_switch, 
+               dcroddsratio_ob = dcroddsratio_ob,
                isinvalidate_ob = isinvalidate_ob)
 
 return(result)
 }
 
-getswitch_fisher <- function(a, b, c, d, thr_p = 0.05, switch_trm = TRUE){
-  if (a > 0 & b > 0 & c > 0 & d > 0){
-    odds_ratio <- fisher_oddsratio(a, b, c, d)
-  } else {
-    odds_ratio <- 1 + 0.1*(a*d-b*c)
-  }
+getswitch_fisher <- function(a, b, c, d, odds_ratio, thr_p = 0.05, switch_trm = TRUE){
+  
   est <- log(odds_ratio)
   n_cnt <- a+b
   n_trm <- c+d
@@ -742,27 +746,27 @@ getswitch_fisher <- function(a, b, c, d, thr_p = 0.05, switch_trm = TRUE){
     d_tryall <- d + c * as.numeric(switch_trm)
     a_tryall <- a + b * (1 - as.numeric(switch_trm))
     b_tryall <- b - b * (1 - as.numeric(switch_trm))
-    if (a_tryall == 0) {a_tryall <- a_tryall + 0.5}
-    if (b_tryall == 0) {b_tryall <- b_tryall + 0.5}
-    if (c_tryall == 0) {c_tryall <- c_tryall + 0.5}
-    if (d_tryall == 0) {d_tryall <- d_tryall + 0.5}
+    # if (a_tryall == 0) {a_tryall <- a_tryall + 0.5}
+    # if (b_tryall == 0) {b_tryall <- b_tryall + 0.5}
+    # if (c_tryall == 0) {c_tryall <- c_tryall + 0.5}
+    # if (d_tryall == 0) {d_tryall <- d_tryall + 0.5}
     tryall_p <- fisher_p(a_tryall, b_tryall, c_tryall, d_tryall)
     tryall_est <- log(a_tryall*d_tryall/c_tryall/b_tryall)
-    allnotenough <- isTRUE((thr_p-tryall_p)*tryall_est< 0 & tryall_est*est > 0)
+    allnotenough <- isTRUE((thr_p-tryall_p)*tryall_est< 0 & tryall_est*est >= 0)
   }
-  if (dcroddsratio_start ) {
+  if (dcroddsratio_start) {
     # transfer cases from A to B or D to C to decrease odds ratio
     c_tryall <- c + d * as.numeric(switch_trm)
     d_tryall <- d - d * as.numeric(switch_trm)
     a_tryall <- a - a * (1 - as.numeric(switch_trm))
     b_tryall <- b + a * (1 - as.numeric(switch_trm))
-    if (a_tryall == 0) {a_tryall <- a_tryall + 0.5}
-    if (b_tryall == 0) {b_tryall <- b_tryall + 0.5}
-    if (c_tryall == 0) {c_tryall <- c_tryall + 0.5}
-    if (d_tryall == 0) {d_tryall <- d_tryall + 0.5}
+    # if (a_tryall == 0) {a_tryall <- a_tryall + 0.5}
+    # if (b_tryall == 0) {b_tryall <- b_tryall + 0.5}
+    # if (c_tryall == 0) {c_tryall <- c_tryall + 0.5}
+    # if (d_tryall == 0) {d_tryall <- d_tryall + 0.5}
     tryall_p <- fisher_p(a_tryall, b_tryall, c_tryall, d_tryall)
     tryall_est <- log(a_tryall*d_tryall/c_tryall/b_tryall)
-    allnotenough <- isTRUE((thr_p-tryall_p)*tryall_est> 0  & tryall_est*est > 0)
+    allnotenough <- isTRUE((thr_p-tryall_p)*tryall_est> 0  & tryall_est*est >= 0)
   }
   
   ### run following if transfering one row is enough
@@ -1039,13 +1043,11 @@ getswitch_fisher <- function(a, b, c, d, thr_p = 0.05, switch_trm = TRUE){
     final_extra <- 0
   }
   
-  total_switch <- final + allnotenough*final_extra
-  
   result <- list(final_switch = final, User_enter_value = table_start, Transfer_Table = table_final, 
                  p_final = p_final, fisher_final = fisher_final,
                  needtworows = allnotenough, taylor_pred = taylor_pred,
                  perc_bias_pred = perc_bias_pred, final_extra = final_extra, 
-                 dcroddsratio_ob = dcroddsratio_ob, total_switch = total_switch, isinvalidate_ob = isinvalidate_ob)
+                 dcroddsratio_ob = dcroddsratio_ob, isinvalidate_ob = isinvalidate_ob)
   
   return(result)
 }
